# Guidelines for Claude

1. The codebase should be focused, clean, and easy to understand.

2. Purge unnecessary code and files.

3. Only use UV to install dependencies and run the python application.

4. Single Source of Truth: DO NOT place many variables in .env file. Place them in the code instead.

5. Run and Debug yourself PROACTIVELY.
